var express = require('express');
var repository = require('../repositories/book');

var routes = function() {
    var bookRouter = express.Router();
    bookRouter.route('/')
        .post(function(req,res){
            var book = repository.create(req.body);
            res.status(201).send(book);
        })
        .get(function(req,res){
            var books = {};
            if (req.query.since && req.query.to)
                books = repository.findByYear(req.query.since,req.query.to);
            else if (req.query.year)
                books = repository.findByYear(req.query.year,req.query.year);
            else
                books = repository.findAll();
            for (var b in books)
            {
                books[b].links = {};
                books[b].links.self = "http://"+req.headers.host + "/api/books/" + books[b].ID;
            }
            res.json(books);
        });

    // middleware
    bookRouter.use('/:bookId', function(req,res,next) {
        var book = repository.findById(req.params.bookId);
        if (book) {
            req.book = book;
            next();
        }
        else {
            res.status(404).send('book not found');
        }
    });
    bookRouter.route('/:bookId')
        .get(function(req,res){
            req.book.links = {};
            req.book.links.filterByYear = "http://"+req.headers.host + "/api/books/?year=" + req.book.Rok;
            res.json(req.book);
        })
        .put(function(req,res){
            req.book.Title = req.body.Title;
            req.book.Author = req.body.Author;
            req.book.Rok = req.body.Rok;
            res.json(req.book);
        })
        .patch(function(req,res){
            if (req.body.ID)
                delete req.body.ID;
            for (var p in req.body)
                req.book[p] = req.body[p];
            res.json(req.book);
        })
        .delete(function(req,res){
            repository.remove(req.book);
            res.status(204).send('book removed');
        });

    return bookRouter
};

module.exports = routes;